@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2019 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -36,6 +36,8 @@
 	#define G_OS_MAC
 #elif defined(__linux__)
 	#define G_OS_LINUX
+#elif defined(__FreeBSD__)
+	#define G_OS_FREEBSD
 #endif
 
 #ifndef BUILD_DATE
@@ -46,10 +48,10 @@
 
 /* -- version --------------------------------------------------------------- */
 constexpr auto G_APP_NAME      = "Giada";
-constexpr auto G_VERSION_STR   = "0.15.4";
+constexpr auto G_VERSION_STR   = "0.16.2";
 constexpr int  G_VERSION_MAJOR = 0;
-constexpr int  G_VERSION_MINOR = 15;
-constexpr int  G_VERSION_PATCH = 4;
+constexpr int  G_VERSION_MINOR = 16;
+constexpr int  G_VERSION_PATCH = 2;
 
 constexpr auto CONF_FILENAME = "giada.conf";
 
@@ -63,56 +65,51 @@ constexpr auto CONF_FILENAME = "giada.conf";
 
 
 /* -- GUI ------------------------------------------------------------------- */
-#define G_GUI_REFRESH_RATE   1000/24
-#define G_GUI_PLUGIN_RATE    0.05  // refresh rate for plugin GUI
-#define G_GUI_FONT_SIZE_BASE 12
-#define G_GUI_INNER_MARGIN   4
-#define G_GUI_OUTER_MARGIN   8
-#define G_GUI_UNIT           20    // base unit for elements 
-#define G_GUI_CHANNEL_H_1    G_GUI_UNIT
-#define G_GUI_CHANNEL_H_2    G_GUI_UNIT * 2
-#define G_GUI_CHANNEL_H_3    G_GUI_UNIT * 4
-#define G_GUI_CHANNEL_H_4    G_GUI_UNIT * 6
-#define G_GUI_ZOOM_FACTOR    2
-
+constexpr float G_GUI_REFRESH_RATE   = 0.05;
+constexpr float G_GUI_PLUGIN_RATE    = 0.05;   // refresh rate for plugin GUI
+constexpr int   G_GUI_FONT_SIZE_BASE = 12;
+constexpr int   G_GUI_INNER_MARGIN   = 4;
+constexpr int   G_GUI_OUTER_MARGIN   = 8;
+constexpr int   G_GUI_UNIT           = 20;    // base unit for elements 
+constexpr int   G_GUI_ZOOM_FACTOR    = 2;
 
 #define G_COLOR_RED       fl_rgb_color(28,  32,  80)
 #define G_COLOR_BLUE      fl_rgb_color(113, 31,  31)
 #define G_COLOR_RED_ALERT fl_rgb_color(239, 75,  53)
-
-#define G_COLOR_LIGHT_2  fl_rgb_color(200, 200, 200)
-#define G_COLOR_LIGHT_1  fl_rgb_color(170, 170, 170)
-#define G_COLOR_GREY_4   fl_rgb_color(78,  78,  78)
-#define G_COLOR_GREY_3   fl_rgb_color(54,  54,  54)
-#define G_COLOR_GREY_2   fl_rgb_color(37,  37,  37)
-#define G_COLOR_GREY_1_5 fl_rgb_color(28,  28,  28)
-#define G_COLOR_GREY_1   fl_rgb_color(25,  25,  25)
-#define G_COLOR_BLACK    fl_rgb_color(0,   0,   0)
+#define G_COLOR_LIGHT_2   fl_rgb_color(200, 200, 200)
+#define G_COLOR_LIGHT_1   fl_rgb_color(170, 170, 170)
+#define G_COLOR_GREY_4    fl_rgb_color(78,  78,  78)
+#define G_COLOR_GREY_3    fl_rgb_color(54,  54,  54)
+#define G_COLOR_GREY_2    fl_rgb_color(37,  37,  37)
+#define G_COLOR_GREY_1_5  fl_rgb_color(28,  28,  28)
+#define G_COLOR_GREY_1    fl_rgb_color(25,  25,  25)
+#define G_COLOR_BLACK     fl_rgb_color(0,   0,   0)
 
 
 
 /* -- MIN/MAX values -------------------------------------------------------- */
-constexpr float G_MIN_BPM          = 20.0f;
-constexpr auto  G_MIN_BPM_STR      = "20.0";
-constexpr float G_MAX_BPM          = 999.0f;
-constexpr auto  G_MAX_BPM_STR      = "999.0";
-constexpr int   G_MAX_BEATS        = 32;
-constexpr int   G_MAX_BARS         = 32;
-constexpr int   G_MAX_QUANTIZE     = 8;
-constexpr float G_MIN_DB_SCALE     = 60.0f;
-constexpr int   G_MIN_COLUMN_WIDTH = 140;
-constexpr float G_MAX_BOOST_DB     = 20.0f;
-constexpr float G_MIN_PITCH        = 0.1f;
-constexpr float G_MAX_PITCH        = 4.0f;
-constexpr int   G_MAX_GRID_VAL     = 64;
-constexpr int   G_MIN_BUF_SIZE     = 8;
-constexpr int   G_MAX_BUF_SIZE     = 4096;
-constexpr int   G_MIN_GUI_WIDTH    = 816;
-constexpr int   G_MIN_GUI_HEIGHT   = 510;
-constexpr int   G_MAX_IO_CHANS     = 2;
-constexpr int   G_MAX_VELOCITY     = 0x7F;
-constexpr int   G_MAX_MIDI_CHANS   = 16;
-constexpr int   G_MAX_POLYPHONY    = 32;
+constexpr float  G_MIN_BPM          = 20.0f;
+constexpr auto   G_MIN_BPM_STR      = "20.0";
+constexpr float  G_MAX_BPM          = 999.0f;
+constexpr auto   G_MAX_BPM_STR      = "999.0";
+constexpr int    G_MAX_BEATS        = 32;
+constexpr int    G_MAX_BARS         = 32;
+constexpr int    G_MAX_QUANTIZE     = 8;
+constexpr float  G_MIN_DB_SCALE     = 60.0f;
+constexpr int    G_MIN_COLUMN_WIDTH = 140;
+constexpr float  G_MAX_BOOST_DB     = 20.0f;
+constexpr float  G_MIN_PITCH        = 0.1f;
+constexpr float  G_MAX_PITCH        = 4.0f;
+constexpr float  G_MAX_VOLUME       = 1.0f;
+constexpr int    G_MAX_GRID_VAL     = 64;
+constexpr int    G_MIN_BUF_SIZE     = 8;
+constexpr int    G_MAX_BUF_SIZE     = 4096;
+constexpr int    G_MIN_GUI_WIDTH    = 816;
+constexpr int    G_MIN_GUI_HEIGHT   = 510;
+constexpr int    G_MAX_IO_CHANS     = 2;
+constexpr int    G_MAX_VELOCITY     = 0x7F;
+constexpr int    G_MAX_MIDI_CHANS   = 16;
+constexpr int    G_MAX_POLYPHONY    = 32;
 
 
 
@@ -138,6 +135,8 @@ constexpr int G_MIDI_API_ALSA = 0x02;  // 0000 0010
 /* -- default system -------------------------------------------------------- */
 #if defined(G_OS_LINUX)
 	#define G_DEFAULT_SOUNDSYS	G_SYS_API_NONE
+#elif defined(G_OS_FREEBSD)
+	#define G_DEFAULT_SOUNDSYS	G_SYS_API_PULSE
 #elif defined(G_OS_WINDOWS)
 	#define G_DEFAULT_SOUNDSYS 	G_SYS_API_DS
 #elif defined(G_OS_MAC)
@@ -154,9 +153,6 @@ constexpr int   G_DEFAULT_BUFSIZE           = 1024;
 constexpr int   G_DEFAULT_BIT_DEPTH         = 32;     // float
 constexpr float G_DEFAULT_VOL               = 1.0f;
 constexpr float G_DEFAULT_PITCH             = 1.0f;
-constexpr float G_DEFAULT_BOOST             = 1.0f;
-constexpr float G_DEFAULT_OUT_VOL           = 1.0f;
-constexpr float G_DEFAULT_IN_VOL            = 1.0f;
 constexpr float G_DEFAULT_BPM               = 120.0f;
 constexpr int   G_DEFAULT_BEATS             = 4;
 constexpr int   G_DEFAULT_BARS              = 1;
@@ -164,63 +160,98 @@ constexpr int   G_DEFAULT_QUANTIZE          = 0;      // quantizer off
 constexpr float G_DEFAULT_FADEOUT_STEP      = 0.01f;  // micro-fadeout speed
 constexpr int   G_DEFAULT_COLUMN_WIDTH      = 380;
 constexpr auto  G_DEFAULT_PATCH_NAME        = "(default patch)";
-constexpr int   G_DEFAULT_MIDI_INPUT_UI_W   = 300;
-constexpr int   G_DEFAULT_MIDI_INPUT_UI_H   = 350;
 constexpr int   G_DEFAULT_ACTION_SIZE       = 8192;  // frames
 constexpr int   G_DEFAULT_ZOOM_RATIO        = 128;
 constexpr float G_DEFAULT_REC_TRIGGER_LEVEL = -10.0f;
+constexpr int   G_DEFAULT_SUBWINDOW_W       = 640;
+constexpr int   G_DEFAULT_SUBWINDOW_H       = 480;
 
 
 
 /* -- responses and return codes -------------------------------------------- */
-#define G_RES_ERR_PROCESSING    -6
-#define G_RES_ERR_WRONG_DATA    -5
-#define G_RES_ERR_NO_DATA       -4
-#define G_RES_ERR_PATH_TOO_LONG -3
-#define G_RES_ERR_IO            -2
-#define G_RES_ERR_MEMORY        -1
-#define G_RES_ERR                0
-#define G_RES_OK                 1
+constexpr int G_RES_ERR_PROCESSING    = -6;
+constexpr int G_RES_ERR_WRONG_DATA    = -5;
+constexpr int G_RES_ERR_NO_DATA       = -4;
+constexpr int G_RES_ERR_PATH_TOO_LONG = -3;
+constexpr int G_RES_ERR_IO            = -2;
+constexpr int G_RES_ERR_MEMORY        = -1;
+constexpr int G_RES_ERR               =  0;
+constexpr int G_RES_OK                =  1;
 
 
 
 /* -- log modes ------------------------------------------------------------- */
-#define LOG_MODE_STDOUT 0x01
-#define LOG_MODE_FILE   0x02
-#define LOG_MODE_MUTE   0x04
+constexpr int LOG_MODE_STDOUT = 0x01;
+constexpr int LOG_MODE_FILE   = 0x02;
+constexpr int LOG_MODE_MUTE   = 0x04;
 
 
 
 /* -- unique IDs of mainWin's subwindows ------------------------------------ */
 /* -- wid > 0 are reserved by gg_keyboard ----------------------------------- */
-#define WID_BEATS         -1
-#define WID_BPM           -2
-#define WID_ABOUT         -3
-#define WID_FILE_BROWSER  -4
-#define WID_CONFIG        -5
-#define WID_FX_LIST       -6
-#define WID_ACTION_EDITOR -7
-#define WID_SAMPLE_EDITOR -8
-#define WID_FX            -9
-#define WID_KEY_GRABBER   -10
-#define WID_SAMPLE_NAME   -11
+constexpr int WID_BEATS         = -1;
+constexpr int WID_BPM           = -2;
+constexpr int WID_ABOUT         = -3;
+constexpr int WID_FILE_BROWSER  = -4;
+constexpr int WID_CONFIG        = -5;
+constexpr int WID_FX_LIST       = -6;
+constexpr int WID_ACTION_EDITOR = -7;
+constexpr int WID_SAMPLE_EDITOR = -8;
+constexpr int WID_FX            = -9;
+constexpr int WID_KEY_GRABBER   = -10;
+constexpr int WID_SAMPLE_NAME   = -11;
+constexpr int WID_FX_CHOOSER    = -12;
+constexpr int WID_MIDI_INPUT    = -13;
+constexpr int WID_MIDI_OUTPUT   = -14;
 
 
 
 /* -- patch signals --------------------------------------------------------- */
-#define PATCH_UNREADABLE    0x01
-#define PATCH_INVALID       0x02
-#define PATCH_READ_OK       0x04
-#define PATCH_WRONG_PLUGINS 0x08  // currently unused
-#define PATCH_WRONG_SAMPLES 0x10  // currently unused
+constexpr int G_PATCH_UNSUPPORTED = -2;
+constexpr int G_PATCH_UNREADABLE  = -1;
+constexpr int G_PATCH_INVALID     =  0;
+constexpr int G_PATCH_OK          =  1;
 
 
 
 /* -- midimap signals ------------------------------------------------------- */
-#define MIDIMAP_NOT_SPECIFIED 0x00
-#define MIDIMAP_UNREADABLE    0x01
-#define MIDIMAP_INVALID       0x02
-#define MIDIMAP_READ_OK       0x04
+constexpr int MIDIMAP_NOT_SPECIFIED = 0x00;
+constexpr int MIDIMAP_UNREADABLE    = 0x01;
+constexpr int MIDIMAP_INVALID       = 0x02;
+constexpr int MIDIMAP_READ_OK       = 0x04;
+
+
+
+/* -- MIDI in parameters (for MIDI learning) -------------------------------- */
+constexpr int G_MIDI_IN_ENABLED      = 1;
+constexpr int G_MIDI_IN_FILTER       = 2;
+constexpr int G_MIDI_IN_REWIND       = 3;
+constexpr int G_MIDI_IN_START_STOP   = 4;
+constexpr int G_MIDI_IN_ACTION_REC   = 5;
+constexpr int G_MIDI_IN_INPUT_REC    = 6;
+constexpr int G_MIDI_IN_METRONOME    = 7;
+constexpr int G_MIDI_IN_VOLUME_IN    = 8;
+constexpr int G_MIDI_IN_VOLUME_OUT   = 9;
+constexpr int G_MIDI_IN_BEAT_DOUBLE  = 10;
+constexpr int G_MIDI_IN_BEAT_HALF    = 11;
+constexpr int G_MIDI_IN_KEYPRESS     = 12;
+constexpr int G_MIDI_IN_KEYREL       = 13;
+constexpr int G_MIDI_IN_KILL         = 14;
+constexpr int G_MIDI_IN_ARM          = 15;
+constexpr int G_MIDI_IN_MUTE         = 16;
+constexpr int G_MIDI_IN_SOLO         = 17;
+constexpr int G_MIDI_IN_VOLUME       = 18;
+constexpr int G_MIDI_IN_PITCH        = 19;
+constexpr int G_MIDI_IN_READ_ACTIONS = 20;
+
+
+
+/* -- MIDI out parameters (for MIDI output and lightning) ------------------- */
+constexpr int G_MIDI_OUT_ENABLED    = 1;
+constexpr int G_MIDI_OUT_L_ENABLED  = 2;
+constexpr int G_MIDI_OUT_L_PLAYING  = 3;
+constexpr int G_MIDI_OUT_L_MUTE     = 4;
+constexpr int G_MIDI_OUT_L_SOLO     = 5;
 
 
 
@@ -262,7 +293,6 @@ constexpr int G_MIDI_CHANS[G_MAX_MIDI_CHANS] = {
 /* JSON patch keys */
 
 constexpr auto PATCH_KEY_HEADER                       = "header";
-constexpr auto PATCH_KEY_VERSION                      = "version";
 constexpr auto PATCH_KEY_VERSION_MAJOR                = "version_major";
 constexpr auto PATCH_KEY_VERSION_MINOR                = "version_minor";
 constexpr auto PATCH_KEY_VERSION_PATCH                = "version_patch";
@@ -277,11 +307,12 @@ constexpr auto PATCH_KEY_METRONOME                    = "metronome";
 constexpr auto PATCH_KEY_LAST_TAKE_ID                 = "last_take_id";
 constexpr auto PATCH_KEY_SAMPLERATE                   = "samplerate";
 constexpr auto PATCH_KEY_COLUMNS                      = "columns";
+constexpr auto PATCH_KEY_PLUGINS                      = "plugins";
 constexpr auto PATCH_KEY_MASTER_OUT_PLUGINS           = "master_out_plugins";
 constexpr auto PATCH_KEY_MASTER_IN_PLUGINS            = "master_in_plugins";
 constexpr auto PATCH_KEY_CHANNELS                     = "channels";
 constexpr auto PATCH_KEY_CHANNEL_TYPE                 = "type";
-constexpr auto PATCH_KEY_CHANNEL_INDEX                = "index";
+constexpr auto PATCH_KEY_CHANNEL_ID                   = "id";
 constexpr auto PATCH_KEY_CHANNEL_SIZE                 = "size";
 constexpr auto PATCH_KEY_CHANNEL_NAME                 = "name";
 constexpr auto PATCH_KEY_CHANNEL_COLUMN               = "column";
@@ -303,13 +334,14 @@ constexpr auto PATCH_KEY_CHANNEL_MIDI_OUT_L           = "midi_out_l";
 constexpr auto PATCH_KEY_CHANNEL_MIDI_OUT_L_PLAYING   = "midi_out_l_playing";
 constexpr auto PATCH_KEY_CHANNEL_MIDI_OUT_L_MUTE      = "midi_out_l_mute";
 constexpr auto PATCH_KEY_CHANNEL_MIDI_OUT_L_SOLO      = "midi_out_l_solo";
-constexpr auto PATCH_KEY_CHANNEL_SAMPLE_PATH          = "sample_path";
+constexpr auto PATCH_KEY_CHANNEL_WAVE_ID              = "wave_id";
 constexpr auto PATCH_KEY_CHANNEL_KEY                  = "key";
 constexpr auto PATCH_KEY_CHANNEL_MODE                 = "mode";
 constexpr auto PATCH_KEY_CHANNEL_BEGIN                = "begin";
 constexpr auto PATCH_KEY_CHANNEL_END                  = "end";
-constexpr auto PATCH_KEY_CHANNEL_BOOST                = "boost";
-constexpr auto PATCH_KEY_CHANNEL_READ_ACTIONS         = "rec_active";  // TODO update string key in 1.0
+constexpr auto PATCH_KEY_CHANNEL_SHIFT                = "shift";
+constexpr auto PATCH_KEY_CHANNEL_HAS_ACTIONS          = "has_actions";
+constexpr auto PATCH_KEY_CHANNEL_READ_ACTIONS         = "read_actions";
 constexpr auto PATCH_KEY_CHANNEL_PITCH                = "pitch";
 constexpr auto PATCH_KEY_CHANNEL_INPUT_MONITOR        = "input_monitor";
 constexpr auto PATCH_KEY_CHANNEL_MIDI_IN_READ_ACTIONS = "midi_in_read_actions";
@@ -317,17 +349,22 @@ constexpr auto PATCH_KEY_CHANNEL_MIDI_IN_PITCH        = "midi_in_pitch";
 constexpr auto PATCH_KEY_CHANNEL_MIDI_OUT             = "midi_out";
 constexpr auto PATCH_KEY_CHANNEL_MIDI_OUT_CHAN        = "midi_out_chan";
 constexpr auto PATCH_KEY_CHANNEL_PLUGINS              = "plugins";
-constexpr auto PATCH_KEY_CHANNEL_ACTIONS              = "actions";
+constexpr auto PATCH_KEY_CHANNEL_PLUGIN_ID            = "plugin_id";
 constexpr auto PATCH_KEY_CHANNEL_ARMED                = "armed";
+constexpr auto PATCH_KEY_WAVES                        = "waves";
+constexpr auto PATCH_KEY_WAVE_ID                      = "id";
+constexpr auto PATCH_KEY_WAVE_PATH                    = "path";
+constexpr auto PATCH_KEY_ACTIONS                      = "actions";
 constexpr auto PATCH_KEY_ACTION_TYPE                  = "type";
 constexpr auto PATCH_KEY_ACTION_FRAME                 = "frame";
 constexpr auto PATCH_KEY_ACTION_F_VALUE               = "f_value";
 constexpr auto PATCH_KEY_ACTION_I_VALUE               = "i_value";
+constexpr auto PATCH_KEY_PLUGIN_ID                    = "id";
 constexpr auto PATCH_KEY_PLUGIN_PATH                  = "path";
 constexpr auto PATCH_KEY_PLUGIN_BYPASS                = "bypass";
 constexpr auto PATCH_KEY_PLUGIN_PARAMS                = "params";
 constexpr auto PATCH_KEY_PLUGIN_MIDI_IN_PARAMS        = "midi_in_params";
-constexpr auto PATCH_KEY_COLUMN_INDEX                 = "index";
+constexpr auto PATCH_KEY_COLUMN_ID                    = "id";
 constexpr auto PATCH_KEY_COLUMN_WIDTH                 = "width";
 constexpr auto PATCH_KEY_COLUMN_CHANNELS              = "channels";
 constexpr auto G_PATCH_KEY_ACTION_ID                  = "id";
@@ -407,16 +444,6 @@ constexpr auto CONF_KEY_VELOCITY_EDITOR_H        = "velocity_editor_h";
 constexpr auto CONF_KEY_ENVELOPE_EDITOR_H        = "envelope_editor_h";
 constexpr auto CONF_KEY_PLUGIN_LIST_X            = "plugin_list_x";
 constexpr auto CONF_KEY_PLUGIN_LIST_Y            = "plugin_list_y";
-constexpr auto CONF_KEY_CONFIG_X                 = "config_x";
-constexpr auto CONF_KEY_CONFIG_Y                 = "config_y";
-constexpr auto CONF_KEY_BPM_X                    = "bpm_x";
-constexpr auto CONF_KEY_BPM_Y                    = "bpm_y";
-constexpr auto CONF_KEY_BEATS_X                  = "beats_x";
-constexpr auto CONF_KEY_BEATS_Y                  = "beats_y";
-constexpr auto CONF_KEY_ABOUT_X                  = "about_x";
-constexpr auto CONF_KEY_ABOUT_Y                  = "about_y";
-constexpr auto CONF_KEY_NAME_X                   = "name_x";
-constexpr auto CONF_KEY_NAME_Y                   = "name_y";
 constexpr auto CONF_KEY_PLUGIN_CHOOSER_X         = "plugin_chooser_x";
 constexpr auto CONF_KEY_PLUGIN_CHOOSER_Y         = "plugin_chooser_y";
 constexpr auto CONF_KEY_PLUGIN_CHOOSER_W         = "plugin_chooser_w";
