@@ -1,12 +1,10 @@
-/* ---------------------------------------------------------------------
+/* -----------------------------------------------------------------------------
  *
  * Giada - Your Hardcore Loopmachine
  *
- * graphics
+ * -----------------------------------------------------------------------------
  *
- * ---------------------------------------------------------------------
- *
- * Copyright (C) 2010-2019 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,10 +22,12 @@
  * along with Giada - Your Hardcore Loopmachine. If not, see
  * <http://www.gnu.org/licenses/>.
  *
- * ------------------------------------------------------------------ */
+ * -------------------------------------------------------------------------- */
+
 
 #include "graphics.h"
 
+
 const char* giada_logo_xpm[] = {
 "245 86 12 1",
 " 	c #191919",
@@ -781,48 +781,6 @@ const char* inputRecOff_xpm[] = {
 "                       ",
 "                       "};
 
-const char* inputToOutputOn_xpm[] = {
-"10 10 8 1",
-" 	c #4D4F4C",
-".	c #585A57",
-"+	c #666765",
-"@	c #6F716E",
-"#	c #939592",
-"$	c #999B98",
-"%	c #AEB0AD",
-"&	c #BCBEBB",
-"          ",
-"          ",
-" .#@      ",
-"  #&&#+   ",
-"    @$&%. ",
-"    @$&%. ",
-"  #&&#+   ",
-" .#@      ",
-"          ",
-"          "};
-
-const char* inputToOutputOff_xpm[] = {
-"10 10 8 1",
-" 	c #242523",
-".	c #2E302D",
-"+	c #3A3B39",
-"@	c #4F514E",
-"#	c #828481",
-"$	c #8B8D8A",
-"%	c #A7A9A6",
-"&	c #B9BBB7",
-"          ",
-"          ",
-" +$@      ",
-" .#&&#+   ",
-"    @$&%. ",
-"    @$&%. ",
-" .#&&#+   ",
-" +$@      ",
-"          ",
-"          "};
-
 const char* muteOff_xpm[] = {
 "18 18 8 1",
 " 	c #242523",
@@ -942,105 +900,163 @@ const char* readActionOn_xpm[] = {
 "                  "};
 
 
+const char* readActionDisabled_xpm[] = {
+"18 18 7 1",
+" 	c None",
+".	c #252525",
+"+	c #313131",
+"@	c #393939",
+"#	c #424242",
+"$	c #4A4A4A",
+"%	c #585858",
+"..................",
+"..................",
+"..................",
+"..................",
+".....@@@@+........",
+".....%%%%%%+......",
+".....%%#+$%$......",
+".....%%@.#%$......",
+".....%%##%%@......",
+".....%%%%%$.......",
+".....%%@+%%#......",
+".....%%@.@%%......",
+".....%%@..%%#.....",
+".....@@...+@@.....",
+"..................",
+"..................",
+"..................",
+".................."};
+
+
 const char* metronomeOff_xpm[] = {
-"13 13 8 1",
-" 	c #242523",
-".	c #2D2928",
-"+	c #34302F",
-"@	c #443D3C",
-"#	c #4F4445",
-"$	c #685659",
-"%	c #826A68",
-"&	c #A18282",
-"             ",
-"             ",
-"  .       .  ",
-" #%       %# ",
-" .&+     +&. ",
-"  %$     $%  ",
-"  @&     &@  ",
-"   &@   @&   ",
-"   $%   %$   ",
-"   +&. .&+   ",
-"    %# #%    ",
-"    .   .    ",
-"             "};
+"13 23 3 1",
+" 	c None",
+".	c #252525",
+"+	c #B18E8E",
+".............",
+".............",
+".............",
+".............",
+".............",
+".............",
+"....+...+....",
+"....+...+....",
+"....+...+....",
+"....+...+....",
+"....+...+....",
+"....+...+....",
+"....+...+....",
+"....+...+....",
+"....+...+....",
+"....+...+....",
+".............",
+".............",
+".............",
+".............",
+".............",
+".............",
+"............."};
 
 
 const char* metronomeOn_xpm[] = {
-"13 13 8 1",
-" 	c #4D4F4C",
-".	c #565150",
-"+	c #645C5C",
-"@	c #716465",
-"#	c #837070",
-"$	c #8F7775",
-"%	c #977C7B",
-"&	c #A68787",
-"             ",
-"             ",
-"  .       .  ",
-" @%       %@ ",
-" .&.     .&. ",
-"  $#     #$  ",
-"  +&     &+  ",
-"   &+   +&   ",
-"   #$   $#   ",
-"   .&. .&.   ",
-"    %@ @%    ",
-"    .   .    ",
-"             "};
+"13 23 3 1",
+" 	c None",
+".	c #4E4E4E",
+"+	c #B18E8E",
+".............",
+".............",
+".............",
+".............",
+".............",
+".............",
+"....+...+....",
+"....+...+....",
+"....+...+....",
+"....+...+....",
+"....+...+....",
+"....+...+....",
+"....+...+....",
+"....+...+....",
+"....+...+....",
+"....+...+....",
+".............",
+".............",
+".............",
+".............",
+".............",
+".............",
+"............."};
 
 
 const char* recTriggerModeOff_xpm[] = {
-"13 13 8 1",
-"   c #242523",
-".  c #272826",
-"+  c #2C2827",
-"@  c #292B28",
-"#  c #493E3F",
-"$  c #6A595B",
-"%  c #896E6D",
-"&  c #B08E8E",
-"@...........@",
-".           .",
-". #$$$$$$$# .",
-". +%&&&&&%+ .",
-".  +%&&&%+  .",
-".   +%&%+   .",
-".    +&+    .",
-".   +%&%+   .",
-".  +%&&&%+  .",
-". +%&&&&&%+ .",
-". #$$$$$$$# .",
-".           .",
-"@...........@"};
+"13 23 8 1",
+" 	c #232523",
+".	c #2A2625",
+"+	c #43393A",
+"@	c #514647",
+"#	c #6F5C59",
+"$	c #8B7170",
+"%	c #AA8889",
+"&	c #B08E8F",
+"             ",
+"             ",
+"             ",
+"             ",
+"             ",
+"     @$@     ",
+"     %&%     ",
+"     $&$     ",
+"     .+.     ",
+"             ",
+"     #%#     ",
+"     %&%     ",
+"     #%#     ",
+"             ",
+"     .+.     ",
+"     $&$     ",
+"     %&%     ",
+"     @$@     ",
+"             ",
+"             ",
+"             ",
+"             ",
+"             "};
 
 
 const char* recTriggerModeOn_xpm[] = {
-"13 13 9 1",
-"   c None",
-".  c #4D4F4C",
-"+  c #544F4E",
-"@  c #675C5C",
-"#  c #6A5F5F",
-"$  c #7D6B6E",
-"%  c #827072",
-"&  c #967B7A",
-"*  c #B18E8F",
-".............",
-".............",
-"..@$$$$$$$@..",
-"..+&*****&+..",
-"...+&***&+...",
-"....+&*&+....",
-".....+*+.....",
-"....+&*&+....",
-"...+&***&+...",
-"..+&*****&+..",
-"..#%%%%%%%#..",
-".............",
-"............."};
+"13 23 8 1",
+" 	c #4D4F4C",
+".	c #534E4D",
+"+	c #605B5A",
+"@	c #6D6363",
+"#	c #817072",
+"$	c #967C7B",
+"%	c #AC8A8B",
+"&	c #B08E8F",
+"             ",
+"             ",
+"             ",
+"             ",
+"             ",
+"     @$@     ",
+"     %&%     ",
+"     $&$     ",
+"     .+.     ",
+"             ",
+"     #%#     ",
+"     %&%     ",
+"     #%#     ",
+"             ",
+"     .+.     ",
+"     $&$     ",
+"     %&%     ",
+"     @$@     ",
+"             ",
+"             ",
+"             ",
+"             ",
+"             "};    
 
 
 const char* zoomInOff_xpm[] = {
