@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2019 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -33,8 +33,7 @@ namespace giada {
 namespace c {
 namespace storage
 {
-void loadPatch  (void* data);
-void savePatch  (void* data);
+void loadProject(void* data);
 void saveProject(void* data);
 void saveSample (void* data);
 void loadSample (void* data);
