@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2019 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -36,8 +36,18 @@ class geBox;
 class geButton;
 
 
+namespace giada {
+namespace v 
+{
 class gdAbout : public gdWindow
 {
+public:
+
+    gdAbout();
+
+    static void cb_close(Fl_Widget* w, void* p);
+    inline void cb_close();
+
 private:
 
 	geBox*    logo;
@@ -48,14 +58,8 @@ private:
 	geBox* vstText;
 	geBox* vstLogo;
 #endif
-
-public:
-
-	gdAbout();
-	~gdAbout();
-
-	static void cb_close(Fl_Widget* w, void* p);
-	inline void cb_close();
 };
+}} // giada::v::
+
 
 #endif
