@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2019 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -37,8 +37,15 @@ class geButton;
 class geCheck;
 
 
+namespace giada {
+namespace v 
+{
 class gdBeatsInput : public gdWindow
 {
+public:
+
+    gdBeatsInput();
+
 private:
 
 	static void cb_update(Fl_Widget* w, void* p);
@@ -47,12 +54,8 @@ private:
 	geInput* beats;
 	geInput* bars;
 	geButton* ok;
-
-public:
-
-	gdBeatsInput();
-	~gdBeatsInput();
 };
+}} // giada::v::
 
 
 #endif
