@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2019 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -29,24 +29,27 @@
 #define GD_DEV_INFO_H
 
 
-#include <FL/Fl_Window.H>
+#include "window.h"
 
 
 class geBox;
 class geButton;
 
 
-class gdDevInfo : public Fl_Window
+namespace giada {
+namespace v 
+{
+class gdDevInfo : public gdWindow
 {
-private:
-
-	geBox   	 *text;
-	geButton *close;
-
 public:
 
-	gdDevInfo(unsigned dev);
-	~gdDevInfo();
+    gdDevInfo(unsigned dev);
+
+private:
+
+	geBox*    text;
+	geButton* close;
 };
+}} // giada::v::
 
 #endif
