@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2019 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -29,8 +29,11 @@
 #define GD_WARNINGS_H
 
 
+namespace giada {
+namespace v 
+{
 void gdAlert(const char *c);
 int  gdConfirmWin(const char *title, const char *msg);
-
+}} // giada::v::
 
 #endif
