@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2019 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -36,9 +36,10 @@ class geRadio : public Fl_Radio_Button
 {
 public:
 
-  geRadio(int x, int y, int w, int h, const char *l=0);
+	geRadio(int x, int y, int w, int h, const char *l=0);
 
-  void draw();
+	void draw() override;
 };
 
+
 #endif
