@@ -7,7 +7,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2019 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -39,12 +39,18 @@ class geStatusButton : public geButton
 {
 public:
 
-	geStatusButton(int x, int y, int w, int h, const char **imgOff=nullptr,
-    const char **imgOn=nullptr);
+	geStatusButton(int x, int y, int w, int h, const char** imgOff=nullptr,
+    const char** imgOn=nullptr, const char** imgDisabled=nullptr);
 
 	void draw() override;
 
-	bool status;
+    bool getStatus() const;
+
+    void setStatus(bool s);
+
+private:
+
+	bool m_status;
 };
 
 
