@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2019 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -35,15 +35,20 @@
 class geChoice;
 
 
+namespace giada {
+namespace v
+{
 class geTabMisc : public Fl_Group
 {
 public:
 
-	geChoice *debugMsg;
-
 	geTabMisc(int x, int y, int w, int h);
 
 	void save();
+
+	geChoice* debugMsg;
 };
+}} // giada::v::
+
 
 #endif
