@@ -6,7 +6,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2019 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -41,8 +41,11 @@ class geBeatMeter : public Fl_Box
 {
 public:
 
-	geBeatMeter(int x, int y, int w, int h, const char* l=nullptr);
-	void draw();
+	geBeatMeter(int x, int y, int w, int h);
+	
+	void draw() override;
+
+	void refresh();
 
 private:
 
