@@ -6,7 +6,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2019 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -34,14 +34,24 @@
 #include <FL/Fl_Box.H>
 
 
+namespace giada {
+namespace m 
+{ 
+class SampleChannel; 
+}
+namespace v
+{
 class geChannelStatus : public Fl_Box
 {
 public:
-	geChannelStatus(int X, int Y, int W, int H, giada::m::SampleChannel *ch,
-    const char *L=0);
-	void draw();
-	giada::m::SampleChannel *ch;
+
+	geChannelStatus(int x, int y, int w, int h, ID channelId);
+
+	void draw() override;
+
+	ID channelId;
 };
+}} // giada::v::
 
 
 #endif
