@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2019 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -25,20 +25,49 @@
  * -------------------------------------------------------------------------- */
 
 
+#include "utils/string.h"
+#include "core/channels/midiChannel.h"
+#include "core/model/model.h"
+#include "core/recManager.h"
 #include "midiChannelButton.h"
 
 
-geMidiChannelButton::geMidiChannelButton(int x, int y, int w, int h, const char* l)
-	: geChannelButton(x, y, w, h, l)
+namespace giada {
+namespace v
 {
+geMidiChannelButton::geMidiChannelButton(int x, int y, int w, int h, ID channelId)
+: geChannelButton(x, y, w, h, channelId)
+{
+    std::string l; 
+	m::model::onGet(m::model::channels, m_channelId, [&](m::Channel& c)
+	{
+		const m::MidiChannel& mc = static_cast<m::MidiChannel&>(c);
+		if (mc.name.empty())
+			l = "-- MIDI --";
+		else
+			l = mc.name.c_str();
+
+		if (mc.midiOut) 
+			l += " (ch " + u::string::iToString(mc.midiOutChan + 1) + " out)";
+	});
+
+    label(l.c_str());
 }
 
 
 /* -------------------------------------------------------------------------- */
 
 
-int geMidiChannelButton::handle(int e)
+void geMidiChannelButton::refresh()
 {
-	// Currently MIDI drag-n-drop does nothing.
-	return geButton::handle(e);
+	geChannelButton::refresh();
+
+	m::model::onGet(m::model::channels, m_channelId, [&](m::Channel& c)
+	{
+		if (m::recManager::isRecordingAction() && c.armed)
+			setActionRecordMode();
+	});
+	
+	redraw();
 }
+}} // giada::v::
