@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2019 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -32,12 +32,22 @@
 #include "channelButton.h"
 
 
+namespace giada {
+namespace m 
+{ 
+class MidiChannel; 
+}
+namespace v
+{
 class geMidiChannelButton : public geChannelButton
 {
 public:
-	geMidiChannelButton(int x, int y, int w, int h, const char* l=0);
-	int handle(int e);
+
+	geMidiChannelButton(int x, int y, int w, int h, ID channelId);
+	
+	void refresh() override;
 };
+}} // giada::v::
 
 
-#endif
\ No newline at end of file
+#endif
