@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2019 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -32,13 +32,24 @@
 #include "channelButton.h"
 
 
+namespace giada {
+namespace m 
+{ 
+class SampleChannel; 
+}
+namespace v
+{
 class geSampleChannelButton : public geChannelButton
 {
 public:
 
-	geSampleChannelButton(int x, int y, int w, int h, const char* l=0);
-	int handle(int e);
+	geSampleChannelButton(int x, int y, int w, int h, ID channelId);
+	
+    int handle(int e) override;
+
+    void refresh() override;
 };
+}} // giada::v::
 
 
 #endif
