@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2019 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -27,6 +27,7 @@
 
 #ifdef WITH_VST
 
+
 #ifndef GE_PLUGIN_BROWSER_H
 #define GE_PLUGIN_BROWSER_H
 
@@ -34,20 +35,25 @@
 #include <FL/Fl_Browser.H>
 
 
+namespace giada {
+namespace v
+{
 class gePluginBrowser : public Fl_Browser
 {
-private:
-
-	int widths[5] = {0};
-
-	void computeWidths();
-
 public:
 
 	gePluginBrowser(int x, int y, int w, int h);
 
 	void refresh();
+
+private:
+
+    void computeWidths();
+
+    int widths[5] = {0};
 };
+}} // giada::v::
+
 
 #endif
 
