@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2019 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2020 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -32,6 +32,9 @@
 #include <FL/Fl_Box.H>
 
 
+namespace giada {
+namespace v
+{
 class geSoundMeter : public Fl_Box
 {
 public:
@@ -47,6 +50,7 @@ private:
 	float m_dbLevelCur;
 	float m_dbLevelOld;
 };
+}} // giada::v::
 
 
 #endif
